@@ -1202,7 +1202,8 @@ class Builder(Update):
                 else:
                     os.rmdir(old_path)
         except OSError as e:
-            self.printWARNING(_("Failed to migrate flash linux directory"))
+            self.printWARNING(
+                _("Failed to move the ISO images directory on the Flash"))
             self.printWARNING(str(e))
         return True
 
