@@ -19,6 +19,7 @@ from calculate.core.server.func import Action
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.files import FilesError
+from calculate.lib.variables.system import RootType
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
@@ -54,24 +55,28 @@ class ClBuilderMenuAction(Action):
         {'name': 'grub:grub_image_menu',
          'method': 'Builder.set_builder_action("%s")' % Actions.ImageMenu,
          },
+        {'name': 'grub:mount_flash_rw',
+         'method': 'Builder.remount_rw(cl_builder_flash_path)',
+         'condition': lambda Get: (
+             Get('os_root_type_ext') in RootType.IsoScanGrub)
+         },
         {'name': 'grub:update_grub_menu',
          'message': __("Creating the ISO images menu"),
          'method': 'Builder.create_iso_grub_cfg(cl_builder_livemenu_path)',
          'condition': lambda Get: (
-             Get('os_root_type') == 'hdd' and
              Get('builder.cl_builder_livemenu_path') != "")
          },
         {'name': 'grub:clear_grub_menu',
          'message': __("Clearing the ISO images menu"),
          'method': 'Builder.clear_iso_grub_cfg(cl_livemenu_path)',
          'condition': lambda Get: (
-             Get('os_root_type') == 'hdd' and
+             Get('os_root_type_ext') in RootType.HDDs and
              Get('builder.cl_builder_livemenu_path') == "")
          },
         {'name': 'grub:setup_grub',
          'message': __("Configuration grub for {cl_builder_livemenu_path}"),
          'method': 'Builder.setup_package("sys-boot/grub")',
-         'condition': lambda Get: (Get('os_root_type') == "hdd" and
+         'condition': lambda Get: (Get('os_root_type_ext') in RootType.HDDs and
                                    Get('builder.cl_builder_livemenu_path') !=
                                    Get('builder.cl_livemenu_path'))
          },
