@@ -1376,18 +1376,6 @@ class VariableClLivemenuPath(ReadonlyVariable):
         return ""
 
 
-class VariableClIsoscanPath(ReadonlyVariable):
-    """
-    Образ с которого загружена система
-    """
-
-    def get(self):
-        root_type_ext = self.Get('os_root_type_ext')
-        if root_type_ext in RootType.IsoScan:
-            return getValueFromCmdLine("iso-scan/filename", 0)
-        return ""
-
-
 class VariableClBuilderLivemenuPath(Variable):
     """
     Путь до устройства flash
@@ -1403,7 +1391,7 @@ class VariableClBuilderLivemenuPath(Variable):
         self.label = _("Path")
 
     def get_isoscan_grub_repository(self):
-        isoscan_path = self.Get('cl_isoscan_path')
+        isoscan_path = self.Get('cl_isoscan_fullpath')
         if isoscan_path:
             return path.dirname(isoscan_path)
         return ""
@@ -1553,6 +1541,10 @@ class VariableClBuilderFlashPath(ReadonlyVariable):
     """
 
     def get(self):
+        typemenu = self.Get('cl_builder_livemenu_type')
+        root_type_ext = self.Get('os_root_type_ext')
+        if root_type_ext in RootType.IsoScanGrub and typemenu == "grub":
+            return Dracut.IsoScanPath
         try:
             iso = self.Get('cl_builder_flash_dev')
             if iso:
